$primary: {{ INDIGO_PRIMARY_COLOR }};

// Theme fonts
$font-family-title: Plex;
$serif: Crimson;
$f-sans-serif: Crimson, 'Open Sans','Helvetica Neue', Helvetica, Arial, sans-serif;

// Initialize the Open edX Bootstrap theme
@import 'edx-bootstrap/sass/open-edx/theme';
